*******************
Examples
*******************

Contents:

.. toctree::
    :maxdepth: 2

    examples/process
    examples/c_py_mem_trace
    examples/dtrace
    examples/debug_malloc_stats
    examples/trace_malloc
